@@ -3,7 +3,7 @@ use warnings;
 
 package App::gcal;
 {
-  $App::gcal::VERSION = '1.113460';
+  $App::gcal::VERSION = '1.120110';
 }
 
 use Class::ReturnValue;
@@ -85,6 +85,10 @@ sub _save_to_gcal {
         require Net::Netrc;
         my $netrc = Net::Netrc->lookup('google.com');
 
+        unless ($netrc) {
+            die('Error. Could not find your credentials in your .netrc file');
+        }
+
         # login
         require Net::Google::Calendar;
         $gcal = Net::Google::Calendar->new;
@@ -154,7 +158,7 @@ App::gcal - Command Line Interface interface to Google Calendar.
 
 =head1 VERSION
 
-version 1.113460
+version 1.120110
 
 =head1 SYNOPSIS
 
@@ -162,12 +166,14 @@ The C<gcal> command provides a quick and easy interface to Google Calendar from
 
 =head1 DESCRIPTION
 
-Before using the C<gcal> command, you need to provide your Google credentials in your C<.netrc> file, for the C<google.com> machine. For example:
+Before using the C<gcal> command, you need to provide your Google credentials in your C<~.netrc> file, for the C<google.com> machine. For example:
 
   machine google.com
   login bob
   password 1234
 
+NOTE: On Windows, your C<.netrc> file is at C<%HOME%.netrc>.
+
 You can then pass one or more C<.ics> files to the C<gcal> command and it will be added to your Google Calendar.
 
 You can also pass one or more strings to the C<gcal> command, which will attempt to parse it and create a new event. It uses L<ICal::QuickAdd> to parse, so has the same functionality and limitations.
@@ -186,7 +192,7 @@ Andrew Jones <andrew@arjones.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Andrew Jones.
+This software is copyright (c) 2012 by Andrew Jones.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
